// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KACTIVITIES_VERSION_H
#define KACTIVITIES_VERSION_H

#define KACTIVITIES_VERSION_STRING "5.116.0"
#define KACTIVITIES_VERSION_MAJOR 5
#define KACTIVITIES_VERSION_MINOR 116
#define KACTIVITIES_VERSION_PATCH 0
#define KACTIVITIES_VERSION ((5<<16)|(116<<8)|(0))

#endif
